/***************************************************************
LanceMan's quickplot --- a fast interactive 2D plotter

Copyright (C) 1998, 1999  Lance Arsenault

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2
of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Or look at http://www.gnu.org/copyleft/gpl.html .

**********************************************************************/
/* $Id: xwin.h,v 1.5 1999/02/27 04:21:59 lance Exp $ */
#include <X11/Intrinsic.h>

/* mouse mode flags available */
#define VALUE_MODE 01
#define EDIT_MODE 02

typedef struct
{
  XtAppContext context;
  Widget toplevelWig, managerWig, plotWig, 
    quitWig, popWig, *valueWig, menuWig ,modeWig, redrawWig, saveButtonWig,
    saveInputWig;
  unsigned long grey_pix;
  XFontStruct *font_struct;
  int savefile_count;
  int  screen_number;
  Display *display;
  Window plotwin, quitwin;
  Pixmap plot0pix;
  unsigned long BWbackground_pix, BWforeground_pix;
  Window valuewin;
  int popflag;
  GC gc;
  int mode; /* mouse mode flag */

} PlotXwins;
